@@ -1,5 +1,5 @@
 ## File Name: SRM_COMPUTE_SEM_SIGMA.R
-## File Version: 0.07
+## File Version: 0.13
 
 
 # compute sigma in a SEM model
@@ -10,15 +10,8 @@ SRM_COMPUTE_SEM_SIGMA <- function( parm_list, level, group=1 )
     LAM <- parm_list1[[ paste0("LAM_", level) ]]
     PHI <- parm_list1[[ paste0("PHI_", level) ]]
     PSI <- parm_list1[[ paste0("PSI_", level) ]]
-    B <- parm_list1[[ paste0("G_", level) ]]
+    B <- parm_list1[[ paste0("B_", level) ]]
     #-- computations
-    if ( ! is.null(B) ){
-        IB <- diag(1, nrow(B) )
-        W <- SRM_GINV( IB - B )
-        LAM_W <- LAM %*% W
-    } else {
-        LAM_W <- LAM
-    }
-    SIGMA <- LAM_W %*% PHI %*% t(LAM_W) + PSI
+    SIGMA <- SRM_COMPUTE_SEM_SIGMA_COMPUTATION(B=B, LAM=LAM, PHI=PHI, PSI=PSI)
     return(SIGMA)
 }
