@@ -1,5 +1,5 @@
 ## File Name: srm.R
-## File Version: 0.6001
+## File Version: 0.625
 
 
 srm <- function(model.syntax = NULL,
@@ -58,6 +58,7 @@ z0 <- Sys.time()
                 parm_list=parm_list, symm_matrices=symm_matrices, include_fixed=TRUE )
 # cat(" *** create parameter lists") ; z1 <- Sys.time(); print(z1-z0) ; z0 <- z1
 
+
     ## Step 2: make list with data
     data_list <- SRM_MAKE_DATA_LIST(srm_data = data, person_names = person_names ,
                             rrgroup_name = rrgroup_name, group.var = group.var,
@@ -169,13 +170,29 @@ z0 <- Sys.time()
     se <- sqrt(diag(vcov))
     parm.table$se <- se[ parm.table$index ]
 
+    #- informations about input data
+    res <- SRM_INFO_INPUT_DATA(data_list=data_list)
+    nrr <- res$nrr
+    npersons <- res$npersons
+    ndyads <- res$ndyads
+
+    # covariance matrices at levels
+    sigma <- list()
+    for (level in c("U","D")){
+        for (gg in 1:ngroups){
+            sigma[[level]][[gg]] <- SRM_COMPUTE_SEM_SIGMA( parm_list=parm_list,
+                                            level=level, group=gg )
+        }
+    }
+
     s2 <- Sys.time()
     time <- list(time_pre=time_pre, time_opt=time_opt, time_post=s2-s1)
 
     #--- output
     res <- list( coef=coef, vcov=vcov, grad=grad, se=se, loglike=loglike, dev=dev,
                     res_opt=res_opt, parm.table=parm.table, parm_list=parm_list,
-                    data_list=data_list, ngroups=ngroups, grad_maxabs=grad_maxabs,
+                    data_list=data_list, ngroups=ngroups, nrr=nrr, npersons=npersons,
+                    ndyads=ndyads, grad_maxabs=grad_maxabs, sigma=sigma,
                     CALL=CALL, time=time, time_start=v1 )
     class(res) <- 'srm'
     return(res)
